@@ -1,4 +1,4 @@
 from .script_runner import ScriptRunner
 from .scripts import DummyScript
 from .scripts import RetrieveStudyListScript
-from .scripts import RetrieveHistogramWithProcedureCountsScript
+from .scripts import RetrieveProcedureCountsAndComplicationsPerQuarterScript
